@@ -4,7 +4,7 @@ from django.contrib import admin
 from django.contrib.admin import sites
 from django.utils.module_loading import import_string
 
-from . import module_settings  # noqa, load module settings
+from django_daisy import module_settings  # noqa, load module settings
 
 if default_admin_site := getattr(settings, 'DEFAULT_ADMIN_SITE_CLASS', None):
     AdminSiteClass = import_string(default_admin_site)
@@ -12,11 +12,6 @@ else:
     AdminSiteClass = import_string('django_daisy.admin.DaisyAdminSite')
 
 
-class LogEntryAdmin(admin.ModelAdmin):
-    def get_model_perms(self, request):
-        return {}
-
-
 class DefaultAppConfig(AppConfig):
     name = "django_daisy"
     default = True
@@ -29,7 +24,7 @@ class DefaultAppConfig(AppConfig):
         admin.site = site
         sites.site = site
 
-        admin.site.register(LogEntry, LogEntryAdmin)
+        admin.site.register(LogEntry, LogentryAdmin)
 
 
 class BasicAppConfig(AppConfig):
