@@ -22,7 +22,7 @@ class JsonEditorWidget(forms.Textarea):
     class Media:
         js = [
             'admin/fields/json-editor/jsoneditor.min.js',
-            'admin/fields/json-editor/init.js'
+            'admin/fields/json-editor/json_editor_init.js'
         ]
 
 
@@ -35,7 +35,7 @@ class JsonEditorField(models.JSONField):
 
     def formfield(self, **kwargs):
         kwargs.update({
-            'widget': JsonEditorWidget(schema_template=json.dumps(self.schema)),
+            'widget': JsonEditorWidget(schema_template=self.schema),
         })
         return super(JsonEditorField, self).formfield(**kwargs)
 
